Machine name
Color tag

Binding
TCP UNIX
:

SSL
SSL certificate file
Generate a self-signed certificate

SSL client authentication
SSL client certificates
No certificates are created yet.

#### {{certificate.user}}

`{{certificate.digest}}`

New certificate

#### New client certificate

#### Generating certificate

This might take a few seconds
Download certificate
Login as
Country
State
Organization
Common name
Save